@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -25,7 +25,7 @@
 import datetime
 
 project = "µsort"
-copyright = f"{datetime.date.today().year}, Facebook Inc."
+copyright = f"{datetime.date.today().year}, Meta Platforms, Inc. and affiliates."
 author = "Tim Hatch"
 
 
@@ -89,7 +89,7 @@ html_sidebars = {
         "navigation.html",
         "relations.html",
         "searchbox.html",
-        "facebook.html",
+        "meta.html",
     ],
 }
 
