@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -6,8 +6,10 @@
 from .cli import CliTest
 from .config import ConfigTest
 from .functional import BasicOrderingTest, UsortStringFunctionalTest
-from .sort_key import IsSortableTest, SortableImportTest
 from .stdlibs import StdlibsTest
+from .translate import IsSortableTest, SortableImportTest
+from .types import TypesTest
+from .util import UtilTest
 
 __all__ = [
     "CliTest",
@@ -17,4 +19,6 @@ __all__ = [
     "IsSortableTest",
     "SortableImportTest",
     "StdlibsTest",
+    "TypesTest",
+    "UtilTest",
 ]
